==> jc-1.4.0.tar.gz: soot/jimple/spark/SparkTransformer.h <==
// public class soot.jimple.spark.SparkTransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 120bc7bd95b93244 soot_jimple_spark_AbstractSparkTransformer
// @dep_class 5bc544b81bcd114d soot_jimple_spark_SparkTransformer

// header file dependencies
// @dep_header soot_jimple_spark_AbstractSparkTransformer

#include "soot/jimple/spark/AbstractSparkTransformer.h"

#ifndef _JC_soot_jimple_spark_SparkTransformer_H_
#define _JC_soot_jimple_spark_SparkTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_spark_SparkTransformer$object;
struct _jc_soot_jimple_spark_pag_PAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_SparkTransformer$sub_refs	_jc_soot_jimple_spark_SparkTransformer$sub_refs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$sub_nonrefs	_jc_soot_jimple_spark_SparkTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$refs	_jc_soot_jimple_spark_SparkTransformer$refs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$nonrefs	_jc_soot_jimple_spark_SparkTransformer$nonrefs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$object	_jc_soot_jimple_spark_SparkTransformer$object;

typedef const struct _jc_soot_jimple_spark_SparkTransformer$vmethods	_jc_soot_jimple_spark_SparkTransformer$vmethods;
typedef const struct _jc_soot_jimple_spark_SparkTransformer$vtable	_jc_soot_jimple_spark_SparkTransformer$vtable;
typedef const struct _jc_soot_jimple_spark_SparkTransformer$vtype	_jc_soot_jimple_spark_SparkTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_SparkTransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_SparkTransformer$method$addTags$08b991c7dc8832bb(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);
extern void _jc_soot_jimple_spark_SparkTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_SparkTransformer$method_info$addTags$08b991c7dc8832bb;
extern _jc_method _jc_soot_jimple_spark_SparkTransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_spark_SparkTransformer$object *_jc_soot_jimple_spark_SparkTransformer$method$v$e064fc699ce013f8(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_spark_SparkTransformer$vmethods {
	void	(*addTags$08b991c7dc8832bb)(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_spark_SparkTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	soot_jimple_spark_AbstractSparkTransformer;
	_jc_soot_jimple_spark_SparkTransformer$vmethods	soot_jimple_spark_SparkTransformer;
};

// Vtype
struct _jc_soot_jimple_spark_SparkTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_SparkTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_SparkTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_SparkTransformer$refs {
    _jc_soot_jimple_spark_SparkTransformer$sub_refs	soot_jimple_spark_SparkTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_SparkTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_SparkTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_jimple_spark_SparkTransformer$sub_nonrefs	soot_jimple_spark_SparkTransformer;
};

// Object instance structure
struct _jc_soot_jimple_spark_SparkTransformer$object {
	_jc_soot_jimple_spark_SparkTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_SparkTransformer$vtype	*vtype;
	_jc_soot_jimple_spark_SparkTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_SparkTransformer$vtype _jc_soot_jimple_spark_SparkTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_SparkTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_SparkTransformer$class_object;

#endif	/* _JC_soot_jimple_spark_SparkTransformer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/SparkTransformer.h <==
// public class soot.jimple.spark.SparkTransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 120bc7bd95b93244 soot_jimple_spark_AbstractSparkTransformer
// @dep_class 5bc544b81bcd114d soot_jimple_spark_SparkTransformer

// header file dependencies
// @dep_header soot_jimple_spark_AbstractSparkTransformer

#include "soot/jimple/spark/AbstractSparkTransformer.h"

#ifndef _JC_soot_jimple_spark_SparkTransformer_H_
#define _JC_soot_jimple_spark_SparkTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_spark_SparkTransformer$object;
struct _jc_soot_jimple_spark_pag_PAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_SparkTransformer$sub_refs	_jc_soot_jimple_spark_SparkTransformer$sub_refs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$sub_nonrefs	_jc_soot_jimple_spark_SparkTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$refs	_jc_soot_jimple_spark_SparkTransformer$refs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$nonrefs	_jc_soot_jimple_spark_SparkTransformer$nonrefs;
typedef struct _jc_soot_jimple_spark_SparkTransformer$object	_jc_soot_jimple_spark_SparkTransformer$object;

typedef const struct _jc_soot_jimple_spark_SparkTransformer$vmethods	_jc_soot_jimple_spark_SparkTransformer$vmethods;
typedef const struct _jc_soot_jimple_spark_SparkTransformer$vtable	_jc_soot_jimple_spark_SparkTransformer$vtable;
typedef const struct _jc_soot_jimple_spark_SparkTransformer$vtype	_jc_soot_jimple_spark_SparkTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_SparkTransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_SparkTransformer$method$addTags$08b991c7dc8832bb(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_SparkTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_SparkTransformer$method_info$addTags$08b991c7dc8832bb;
extern _jc_method _jc_soot_jimple_spark_SparkTransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_spark_SparkTransformer$object *_jc_soot_jimple_spark_SparkTransformer$method$v$e064fc699ce013f8(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_SparkTransformer$vmethods {
	void	(*addTags$08b991c7dc8832bb)(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_spark_SparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_SparkTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	soot_jimple_spark_AbstractSparkTransformer;
	_jc_soot_jimple_spark_SparkTransformer$vmethods	soot_jimple_spark_SparkTransformer;
};

// Vtype
struct _jc_soot_jimple_spark_SparkTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_SparkTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_SparkTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_SparkTransformer$refs {
    _jc_soot_jimple_spark_SparkTransformer$sub_refs	soot_jimple_spark_SparkTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_SparkTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_SparkTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_jimple_spark_SparkTransformer$sub_nonrefs	soot_jimple_spark_SparkTransformer;
};

// Object instance structure
struct _jc_soot_jimple_spark_SparkTransformer$object {
	_jc_soot_jimple_spark_SparkTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_SparkTransformer$vtype	*vtype;
	_jc_soot_jimple_spark_SparkTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_SparkTransformer$vtype _jc_soot_jimple_spark_SparkTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_SparkTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_SparkTransformer$class_object;

#endif	/* _JC_soot_jimple_spark_SparkTransformer_H_ */
